# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/hamel',
                'doc_host': 'https://hamelsmu.github.io',
                'git_url': 'https://github.com/hamelsmu/hamel',
                'lib_path': 'hamel'},
  'syms': { 'hamel.annotate_talk_cli': {},
            'hamel.chapters_cli': {},
            'hamel.gem': { 'hamel.gem._build_config': ('gem.html#_build_config', 'hamel/gem.py'),
                           'hamel.gem._chunk_text': ('gem.html#_chunk_text', 'hamel/gem.py'),
                           'hamel.gem._client': ('gem.html#_client', 'hamel/gem.py'),
                           'hamel.gem._content_payload': ('gem.html#_content_payload', 'hamel/gem.py'),
                           'hamel.gem._generate_content': ('gem.html#_generate_content', 'hamel/gem.py'),
                           'hamel.gem._is_media_file': ('gem.html#_is_media_file', 'hamel/gem.py'),
                           'hamel.gem._is_url': ('gem.html#_is_url', 'hamel/gem.py'),
                           'hamel.gem._make_part': ('gem.html#_make_part', 'hamel/gem.py'),
                           'hamel.gem._make_part_async': ('gem.html#_make_part_async', 'hamel/gem.py'),
                           'hamel.gem._mime_for_path': ('gem.html#_mime_for_path', 'hamel/gem.py'),
                           'hamel.gem._normalize_attachments': ('gem.html#_normalize_attachments', 'hamel/gem.py'),
                           'hamel.gem._parts_from_attachments': ('gem.html#_parts_from_attachments', 'hamel/gem.py'),
                           'hamel.gem._parts_from_attachments_async': ('gem.html#_parts_from_attachments_async', 'hamel/gem.py'),
                           'hamel.gem._stream_generate_content': ('gem.html#_stream_generate_content', 'hamel/gem.py'),
                           'hamel.gem._to_thread': ('gem.html#_to_thread', 'hamel/gem.py'),
                           'hamel.gem.gem': ('gem.html#gem', 'hamel/gem.py'),
                           'hamel.gem.gem_async': ('gem.html#gem_async', 'hamel/gem.py'),
                           'hamel.gem.upload_file': ('gem.html#upload_file', 'hamel/gem.py'),
                           'hamel.gem.upload_file_async': ('gem.html#upload_file_async', 'hamel/gem.py')},
            'hamel.gem_cli': {},
            'hamel.kit_cli': {},
            'hamel.transcribe_cli': {},
            'hamel.writing': { 'hamel.writing.gather_urls': ('writing.html#gather_urls', 'hamel/writing.py'),
                               'hamel.writing.generate_annotated_talk_post': ( 'writing.html#generate_annotated_talk_post',
                                                                               'hamel/writing.py'),
                               'hamel.writing.jina_get': ('writing.html#jina_get', 'hamel/writing.py'),
                               'hamel.writing.outline_slides': ('writing.html#outline_slides', 'hamel/writing.py'),
                               'hamel.writing.pdf2imgs': ('writing.html#pdf2imgs', 'hamel/writing.py')},
            'hamel.yt': { 'hamel.yt._extract_video_id': ('yt.html#_extract_video_id', 'hamel/yt.py'),
                          'hamel.yt._format_seconds': ('yt.html#_format_seconds', 'hamel/yt.py'),
                          'hamel.yt._format_timestamp': ('yt.html#_format_timestamp', 'hamel/yt.py'),
                          'hamel.yt.transcribe': ('yt.html#transcribe', 'hamel/yt.py'),
                          'hamel.yt.transcribe_local_video': ('yt.html#transcribe_local_video', 'hamel/yt.py'),
                          'hamel.yt.yt_chapters': ('yt.html#yt_chapters', 'hamel/yt.py')},
            'hamel.zoom': { 'hamel.zoom.download_transcript': ('zoom.html#download_transcript', 'hamel/zoom.py'),
                            'hamel.zoom.get_zoom_token': ('zoom.html#get_zoom_token', 'hamel/zoom.py'),
                            'hamel.zoom.list_recordings': ('zoom.html#list_recordings', 'hamel/zoom.py'),
                            'hamel.zoom.main': ('zoom.html#main', 'hamel/zoom.py'),
                            'hamel.zoom.make_filename': ('zoom.html#make_filename', 'hamel/zoom.py')},
            'hamel.zoom_cli': {}}}
